import 'package:dio/dio.dart';
import 'package:flutter_test_app/data/mappers/characters_mapper.dart';
import 'package:pretty_dio_logger/pretty_dio_logger.dart';

import '../../domain/models/card.dart';
import '../dtos/characters_dto.dart';
import 'api_interface.dart';

class AgentsRepository extends ApiInterface {
  static final Dio _dio = Dio()
    ..interceptors.add(PrettyDioLogger(
      requestHeader: true,
      requestBody: true,
    ));

  static const String _baseUrl = 'https://valorant-api.com/v1/agents';

  @override
  Future<List<CardData>?> loadData({String? q}) async {
    try {
      // Формирование URL для запроса
      final Response<dynamic> response = await _dio.get(_baseUrl);

      // Получение данных агентов из API
      final agentsData = response.data['data'] as List<dynamic>;

      // Преобразование данных JSON в CharactersDto, затем в CardData
      final CharactersDto dto = CharactersDto.fromJson({'data': agentsData});
      List<CardData>? data = dto.data?.map((e) => e.toDomain()).toList();

      // Фильтрация данных по displayName
      if (q != null && q.isNotEmpty) {
        data = data?.where((agent) =>
        agent.text?.toLowerCase().contains(q.toLowerCase()) ?? false).toList();
      }

      return data;
    } on DioException catch (e) {
      // Обработка ошибок запроса
      print('Ошибка при загрузке данных: $e');
      return null;
    }
  }
}
