import 'package:flutter_test_app/data/repositories/mock_repository.dart';
import 'package:flutter_test_app/main.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

import '../../data/repositories/characters_repository.dart';
import '../../domain/models/card.dart';
import '../details_page/details_page.dart';


part 'card.dart';

class MyHomePage extends StatefulWidget {
  const MyHomePage({super.key, required this.title});

  final String title;

  @override
  State<MyHomePage> createState() => _MyHomePageState();
}

class _MyHomePageState extends State<MyHomePage> {
  final Color _color = Colors.orangeAccent;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        backgroundColor: _color,
        title: Text(widget.title),
      ),
      body: const Body(),
    );
  }
}

class Body extends StatefulWidget {
  const Body({super.key});

  @override
  State<Body> createState() => _BodyState();
}

class _BodyState extends State<Body> {
  final searchController = TextEditingController();
  final ScrollController _scrollController = ScrollController();
  late Future<List<CardData>?> data;
  final repo = AgentsRepository();

  @override
  void initState() {
    data = repo.loadData();
    super.initState();
  }

  @override
  void dispose() {
    searchController.dispose();
    _scrollController.dispose();
    super.dispose();
  }

  // Метод для прокрутки к определённой карточке
  void _scrollToCard(String searchQuery, List<CardData>? dataList) {
    if (dataList == null || dataList.isEmpty) return;

    final index = dataList.indexWhere((data) =>
    data.text?.toLowerCase() == searchQuery.toLowerCase());

    if (index != -1) {
      _scrollController.animateTo(
        index * 180.0, // Высота элемента списка с учётом padding и margin
        duration: const Duration(seconds: 1),
        curve: Curves.easeInOut,
      );
    }
  }

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: EdgeInsets.only(top: MediaQuery.of(context).padding.top),
      child: Column(
        children: [
          Padding(
            padding: const EdgeInsets.all(12),
            child: CupertinoSearchTextField(
              controller: searchController,
              onSubmitted: (search) {
                data.then((dataList) {
                  _scrollToCard(search, dataList);
                });
              },
            ),
          ),
          Expanded(
            child: Center(
              child: FutureBuilder<List<CardData>?>(
                future: data,
                builder: (context, snapshot) {
                  if (snapshot.connectionState == ConnectionState.waiting) {
                    return const CircularProgressIndicator();
                  } else if (snapshot.hasError) {
                    return Text('Error: ${snapshot.error}');
                  } else if (snapshot.hasData && snapshot.data != null) {
                    return ListView.builder(
                      controller: _scrollController,
                      itemCount: snapshot.data!.length,
                      itemBuilder: (context, index) {
                        final cardData = snapshot.data![index];
                        return _Card.fromData(
                          cardData,
                          onLike: (String title, bool isLiked) =>
                              _showSnackBar(context, title, isLiked),
                          onTap: () => _navToDetails(context, cardData),
                        );
                      },
                    );
                  } else {
                    return const Text('No data available');
                  }
                },
              ),
            ),
          ),
        ],
      ),
    );
  }

  void _navToDetails(BuildContext context, CardData data) {
    Navigator.push(
      context,
      CupertinoPageRoute(builder: (context) => DetailsPage(data)),
    );
  }

  void _showSnackBar(BuildContext context, String title, bool isLiked) {
    WidgetsBinding.instance.addPostFrameCallback((_) {
      ScaffoldMessenger.of(context).showSnackBar(SnackBar(
        content: Text(
          'News $title ${isLiked ? 'liked' : 'disliked '}',
          style: Theme.of(context).textTheme.bodyLarge,
        ),
        backgroundColor: Colors.deepPurpleAccent,
        duration: const Duration(seconds: 1),
      ));
    });
  }
}

